@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: BBSThreadManager.h 1944 2006-11-07 14:35:58Z svn $
+ * $Id: BBSThreadManager.h 1958 2006-11-11 02:54:28Z svn $
  *****************************************************************************/
 
 #ifndef BBS_THREAD_MANAGER_H
@@ -71,7 +71,7 @@ public:
      * @param[out] indexes_sort_by_view  インデックスの配列
      */
     void get_thread_info_sort_by_view(apr_pool_t *pool,
-                                      apr_size_t *thread_count,
+                                      apr_uint16_t *thread_count,
                                       apr_size_t **ids_sort_by_view,
                                       apr_uint16_t **indexes_sort_by_view) const;
     /**
@@ -151,7 +151,7 @@ public:
      * @param[in] is_age age かどうか
      * @return コメント番号
      */
-    apr_size_t add_comment(apr_size_t thread_id,
+    apr_uint16_t add_comment(apr_size_t thread_id,
                            const char *name, const char *trip,
                            const char *email, const char *message,
                            BBSThread::image_t *image, apr_time_t time,
@@ -160,7 +160,7 @@ public:
      * メモリ上にあるスレッドデータをディスクに書き出します．
      */
     void sync_all_thread();
-    apr_size_t get_thread_count() const
+    apr_uint16_t get_thread_count() const
     {
         return *thread_count_;
     };
@@ -357,9 +357,9 @@ private:
      * @param[in] is_insert 挿入かどうか (true: 挿入)
      */
     template<class T> void update_array(T *array, T i, bool is_insert);
-    void sort_indexes_by_mtime(apr_size_t left=0,
-                               apr_size_t right=MGR_ON_MEMORY_THREAD_COUNT - 1);
-    int cmp_indexes_by_mtime(apr_size_t left, apr_size_t right) const;
+    void sort_indexes_by_mtime(apr_uint16_t left=0,
+                               apr_uint16_t right=MGR_ON_MEMORY_THREAD_COUNT - 1);
+    int cmp_indexes_by_mtime(apr_uint16_t left, apr_uint16_t right) const;
 
     apr_pool_t *pool_;
 
@@ -393,7 +393,7 @@ private:
     /** スレッドへの参照の数 (in in 共有メモリ) */
     apr_atomic_t *threads_ref_count_;
     /** 管理しているスレッドの個数 (in 共有メモリ) */
-    apr_size_t *thread_count_;
+    apr_uint16_t *thread_count_;
 };
 
 #endif
