@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: BBSThread.cpp 1898 2006-10-26 17:46:14Z svn $
+ * $Id: BBSThread.cpp 1951 2006-11-08 11:31:58Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -41,7 +41,7 @@
 #include "Auxiliary.h"
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: BBSThread.cpp 1898 2006-10-26 17:46:14Z svn $");
+SOURCE_INFO_ADD("$Id: BBSThread.cpp 1951 2006-11-08 11:31:58Z svn $");
 
 #define AS_BCOMMENT(pointer)        reinterpret_cast<bbs_comment_t *>(pointer)
 #define UINT16(pointer)             static_cast<apr_uint16_t>(pointer)
@@ -77,7 +77,8 @@ BBSThread::BBSThread()
 
 void BBSThread::add_comment(const char *name, const char *trip,
                             const char *email, const char *message,
-                            apr_time_t time, bool is_age)
+                            BBSThread::image_t *image, apr_time_t time,
+                            bool is_age)
 {
     bbs_comment_t *bcomment;
 
@@ -85,7 +86,8 @@ void BBSThread::add_comment(const char *name, const char *trip,
         THROW(MESSAGE_COMMENT_COUNT_EXCEEDED);
     }
 
-    bcomment = add_comment_data(name, trip, email, message, time, is_age);
+    bcomment = add_comment_data(name, trip, email, message, image, time,
+                                is_age);
 
     if ((bthread_.comment_count & COMMENT_OFFSET_MASK) == 0) {
         bthread_.comment_offsets[bthread_.comment_count >> COMMENT_OFFSET_SHIFT]
@@ -107,19 +109,21 @@ apr_size_t BBSThread::get_valid_size() const
 }
 
 BBSThread *BBSThread::get_instance(void *memory, apr_size_t thread_id,
-                                   const char *subject, image_t *image,
-                                   apr_time_t time)
+                                   const char *subject, apr_time_t time,
+                                   bool is_need_validate)
 {
     BBSThread *bbs_thread;
 
+    if (is_need_validate) {
+        PostDataChecker::validate_thread(subject);
+    }
+
     memset(memory, 0, MAX_THREAD_DATA_SIZE);
     bbs_thread = new(memory) BBSThread;
 
     bbs_thread->bthread_.id = thread_id;
     strncpy(bbs_thread->bthread_.subject, subject, TRD_MAX_SUBJECT_SIZE);
 
-    memcpy(&(bbs_thread->bthread_.image), image, sizeof(image_t));
-
     bbs_thread->bthread_.ctime = time;
     bbs_thread->bthread_.mtime = time;
     bbs_thread->bthread_.atime = time;
@@ -127,14 +131,6 @@ BBSThread *BBSThread::get_instance(void *memory, apr_size_t thread_id,
     return bbs_thread;
 }
 
-BBSThread *BBSThread::get_instance(void *memory, apr_size_t thread_id,
-                                   const char *subject, apr_time_t time)
-{
-    image_t image;
-
-    return get_instance(memory, thread_id, subject, &image, time);
-}
-
 BBSThread *BBSThread::get_instance(apr_pool_t *pool, apr_size_t thread_id,
                                    const char *subject, apr_time_t time)
 {
@@ -142,7 +138,7 @@ BBSThread *BBSThread::get_instance(apr_pool_t *pool, apr_size_t thread_id,
 
     APR_PCALLOC(memory, void *, pool, MAX_THREAD_DATA_SIZE);
 
-    return get_instance(memory, thread_id, subject, time);
+    return get_instance(memory, thread_id, subject, time, false);
 }
 
 #ifdef DEBUG
@@ -162,6 +158,7 @@ BBSThread::bbs_comment_t *BBSThread::add_comment_data(const char *name,
                                                       const char *trip,
                                                       const char *email,
                                                       const char *message,
+                                                      BBSThread::image_t *image,
                                                       apr_time_t time,
                                                       bool is_age)
 {
@@ -170,8 +167,8 @@ BBSThread::bbs_comment_t *BBSThread::add_comment_data(const char *name,
     const char *date;
     TemporaryPool temp_pool;
 
-    PostDataChecker::validate_comment(name, trip, email, message, is_age,
-                                      &flag);
+    PostDataChecker::validate_comment(name, trip, email, message, image,
+                                      is_age, &flag);
 
     date = get_formatted_date(temp_pool.get(), time);
 
@@ -197,6 +194,10 @@ BBSThread::bbs_comment_t *BBSThread::add_comment_data(const char *name,
     strncpy(AS_CHAR(bcomment + 1) + bcomment->message_offset, message,
             TRD_MAX_MESSAGE_SIZE);
 
+    if (image->size != 0) {
+        memcpy(&(bcomment->image), image, sizeof(BBSThread::image_t));
+    }
+
     bcomment->size = sizeof(bbs_comment_t) +
         bcomment->message_offset + bcomment->message_length + 1;
     // アライメントを考慮
@@ -205,15 +206,6 @@ BBSThread::bbs_comment_t *BBSThread::add_comment_data(const char *name,
     return bcomment;
 }
 
-void BBSThread::validate_comment(const char *name, const char *trip,
-                                 const char *email, const char *message,
-                                 bool is_age,
-                                 BBSThread::bbs_comment_flag_t *flag) const
-{
-    PostDataChecker::validate_comment(name, trip, email, message,
-                                      is_age, flag);
-}
-
 void BBSThread::validate_no(apr_size_t no) const
 {
     // Message.h をヘッダファイルで include するのを避けたかったので関
@@ -276,18 +268,17 @@ void run_size()
     show_item("- version", OFFSETOF(BBSThread::bbs_thread_t, version));
     show_item("- subject", OFFSETOF(BBSThread::bbs_thread_t, subject));
     show_item("- status", OFFSETOF(BBSThread::bbs_thread_t, status));
-    show_item("- image", OFFSETOF(BBSThread::bbs_thread_t, image));
     show_item("- id", OFFSETOF(BBSThread::bbs_thread_t, id));
     show_item("- mtime", OFFSETOF(BBSThread::bbs_thread_t, mtime));
     show_item("- atime", OFFSETOF(BBSThread::bbs_thread_t, atime));
     show_item("- ctime", OFFSETOF(BBSThread::bbs_thread_t, ctime));
+    show_item("- comment_end_offset",
+              OFFSETOF(BBSThread::bbs_thread_t, comment_end_offset));
     show_item("- comment_count",
               OFFSETOF(BBSThread::bbs_thread_t, comment_count));
     show_item("- unsynced_comment_count",
               OFFSETOF(BBSThread::bbs_thread_t, unsynced_comment_count));
     show_item("- view_count", OFFSETOF(BBSThread::bbs_thread_t, view_count));
-    show_item("- comment_end_offset",
-              OFFSETOF(BBSThread::bbs_thread_t, comment_end_offset));
     show_item("- comment_offsets",
               OFFSETOF(BBSThread::bbs_thread_t, comment_offsets));
 
@@ -306,6 +297,7 @@ void run_size()
               OFFSETOF(BBSThread::bbs_comment_t, message_offset));
     show_item("- message_length",
               OFFSETOF(BBSThread::bbs_comment_t, message_length));
+    show_item("- image", OFFSETOF(BBSThread::bbs_comment_t, image));
     show_item("- flag", OFFSETOF(BBSThread::bbs_comment_t, flag));
 
     if (sizeof(BBSThread) != sizeof(BBSThread::bbs_thread_t)) {
