@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: BBSThreadList.cpp 1937 2006-11-07 11:45:41Z svn $
+ * $Id: BBSThreadList.cpp 1957 2006-11-11 02:41:33Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -38,7 +38,7 @@
 #include "Auxiliary.h"
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: BBSThreadList.cpp 1937 2006-11-07 11:45:41Z svn $");
+SOURCE_INFO_ADD("$Id: BBSThreadList.cpp 1957 2006-11-11 02:41:33Z svn $");
 
 #define AS_BINFO_T(pointer) reinterpret_cast<BBSThread::info_t *>(pointer)
 #define AS_BTHREAD_T(pointer) reinterpret_cast<BBSThread::bbs_thread_t *>(pointer)
@@ -134,11 +134,11 @@ void BBSThreadList::get_info_list(BBSThread::info_t *info_list,
 }
 
 void BBSThreadList::get_ids(apr_pool_t *pool, apr_size_t *ids,
-                            apr_size_t *count)
+                            apr_uint16_t *count)
 {
-    *count = min(*count, info_list_size_);
+    *count = min(*count, static_cast<apr_uint16_t>(info_list_size_));
 
-    for (apr_size_t i = 0; i < *count; i++) {
+    for (apr_uint16_t i = 0; i < *count; i++) {
         ids[i] = info_list_[i].id;
     }
 }
