@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: ReadWriteAttacker.cpp 1943 2006-11-07 13:09:46Z svn $
+ * $Id: ReadWriteAttacker.cpp 1957 2006-11-11 02:41:33Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -44,11 +44,11 @@
 #include "Macro.h"
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: ReadWriteAttacker.cpp 1943 2006-11-07 13:09:46Z svn $");
+SOURCE_INFO_ADD("$Id: ReadWriteAttacker.cpp 1957 2006-11-11 02:41:33Z svn $");
 
 #define AS_THREAD_START(pointer)    reinterpret_cast<apr_thread_start_t>(pointer)
 
-static const apr_size_t READ_THREAD_COUNT   = 10;
+static const apr_uint16_t READ_THREAD_COUNT = 10;
 static const apr_size_t WRITE_THREAD_COUNT  = 3;
 static const apr_size_t RUN_ITER_COUNT      = 5;
 
@@ -68,7 +68,7 @@ typedef struct thread_context {
     apr_atomic_t write_finish_count;
 
     apr_size_t read_worker_count;
-    apr_size_t read_thread_count;
+    apr_uint16_t read_thread_count;
     apr_atomic_t read_finish_count;
 
     apr_thread_mutex_t *finish_mutex;
@@ -175,7 +175,7 @@ static void APR_THREAD_FUNC read_attack_worker_by_index(apr_thread_t *thread,
 
 static void init_context(apr_pool_t *pool,
                          apr_size_t write_thread_count,
-                         apr_size_t read_thread_count,
+                         apr_uint16_t read_thread_count,
                          apr_size_t write_worker_count,
                          apr_size_t read_worker_count,
                          apr_size_t *write_ids,
