@@ -10,13 +10,16 @@ use WWW::SourceforgeJP;
 use constant PROJECT    => 'mod-fast-bbs';
 use constant USER       => 'kimata';
 
+my $pass;
 my %args = ();
 my $sf;
 
 GetOptions(\%args, "package=s", "mode=s", "version=s", "file=s");
 
+$pass = $ENV{'PASS'} || read_password('sourceforge pass: ', 0, 1);
+
 $sf = WWW::SourceforgeJP->new(PROJECT);
-$sf->login(USER, read_password('sourceforge pass: ', 0, 1));
+$sf->login(USER, $pass);
 
 if ($args{'mode'} eq 'release') {
     die '--file ꤵƤޤ' unless (defined $args{'file'});
@@ -26,18 +29,19 @@ if ($args{'mode'} eq 'release') {
 } else {
     my @links = $sf->get_release_links();
     my $src_link = (grep($_->text() =~ /^mod_fast_bbs-.*\.tgz$/, @links))[0];
-    my $win32_bin_link = (grep($_->text() =~ /^mod_fast_bbs\.so-.*\.zip$/, @links))[0];
+    my $win32_bin_link = (grep($_->text() =~ /^mod_fast_bbs-.*\.msi$/, @links))[0];
 
     while (<>) {
         if (/\* `mod_fast_bbs-\d+\.\d+\.\d+\.tgz/) {
             print << "__HTML__";
 * `@{[$src_link->text()]}[0] <@{[$src_link->url()]}[0]>`_
 __HTML__
-        } elsif (/\* `mod_fast_bbs\.so-\d+\.\d+\.\d+\.zip/) {
+        } elsif (/\* `mod_fast_bbs-\d+\.\d+\.\d+\.msi/) {
             print << "__HTML__";
 * `@{[$win32_bin_link->text()]}[0] <@{[$win32_bin_link->url()]}[0]>`_
 __HTML__
         } else {
+            s/mod_fast_bbs-.*\.msi/$win32_bin_link->text()/eg;
             print;
         }
     }
